Class: Daytona::ListSecretsResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/daytona/common/response.rb

Overview

Cursor-paginated collection of Secrets returned by SecretService#list. Pass next_cursor back as the cursor of the next call to fetch the following page; it is nil when there are no more pages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(items:, total:, next_cursor:) ⇒ ListSecretsResponse

Returns a new instance of ListSecretsResponse.

Parameters:



57
58
59
60
61
# File 'lib/daytona/common/response.rb', line 57

def initialize(items:, total:, next_cursor:)
  @items = items
  @total = total
  @next_cursor = next_cursor
end

Instance Attribute Details

#itemsArray<Daytona::Secret> (readonly)

Returns:



46
47
48
# File 'lib/daytona/common/response.rb', line 46

def items
  @items
end

#next_cursorString? (readonly)

Returns:

  • (String, nil)


52
53
54
# File 'lib/daytona/common/response.rb', line 52

def next_cursor
  @next_cursor
end

#totalFloat (readonly)

Returns:

  • (Float)


49
50
51
# File 'lib/daytona/common/response.rb', line 49

def total
  @total
end