Class: Daytona::CreateSandboxFromSnapshotParams
- Inherits:
-
CreateSandboxBaseParams
- Object
- CreateSandboxBaseParams
- Daytona::CreateSandboxFromSnapshotParams
- Defined in:
- lib/daytona/common/daytona.rb
Instance Attribute Summary collapse
-
#snapshot ⇒ String?
Name of the snapshot to use for the Sandbox.
Attributes inherited from CreateSandboxBaseParams
#auto_archive_interval, #auto_delete_interval, #auto_stop_interval, #env_vars, #ephemeral, #labels, #language, #network_allow_list, #network_block_all, #os_user, #public, #timeout, #volumes
Instance Method Summary collapse
-
#initialize(snapshot: nil, **args) ⇒ CreateSandboxFromSnapshotParams
constructor
Initialize CreateSandboxFromSnapshotParams.
-
#to_h ⇒ Hash<Symbol, Object>
Convert to hash representation.
Constructor Details
#initialize(snapshot: nil, **args) ⇒ CreateSandboxFromSnapshotParams
Initialize CreateSandboxFromSnapshotParams
193 194 195 196 197 |
# File 'lib/daytona/common/daytona.rb', line 193 def initialize(snapshot: nil, **args) @snapshot = snapshot super(**args) end |
Instance Attribute Details
#snapshot ⇒ String?
Returns Name of the snapshot to use for the Sandbox.
175 176 177 |
# File 'lib/daytona/common/daytona.rb', line 175 def snapshot @snapshot end |
Instance Method Details
#to_h ⇒ Hash<Symbol, Object>
Convert to hash representation
202 203 204 |
# File 'lib/daytona/common/daytona.rb', line 202 def to_h super.merge(snapshot:).compact end |