Class: Daytona::CreateSnapshotParams
- Inherits:
-
Object
- Object
- Daytona::CreateSnapshotParams
- Defined in:
- lib/daytona/common/snapshot.rb
Instance Attribute Summary collapse
-
#entrypoint ⇒ Array<String>?
readonly
Entrypoint of the snapshot.
-
#image ⇒ String, Daytona::Image
readonly
Image of the snapshot.
-
#name ⇒ String
readonly
Name of the snapshot.
-
#region_id ⇒ String?
readonly
ID of the region where the snapshot will be available.
-
#resources ⇒ Daytona::Resources?
readonly
Resources of the snapshot.
Instance Method Summary collapse
-
#initialize(name:, image:, resources: nil, entrypoint: nil, region_id: nil) ⇒ CreateSnapshotParams
constructor
A new instance of CreateSnapshotParams.
Constructor Details
#initialize(name:, image:, resources: nil, entrypoint: nil, region_id: nil) ⇒ CreateSnapshotParams
Returns a new instance of CreateSnapshotParams.
28 29 30 31 32 33 34 |
# File 'lib/daytona/common/snapshot.rb', line 28 def initialize(name:, image:, resources: nil, entrypoint: nil, region_id: nil) @name = name @image = image @resources = resources @entrypoint = entrypoint @region_id = region_id end |
Instance Attribute Details
#entrypoint ⇒ Array<String>? (readonly)
Returns Entrypoint of the snapshot.
17 18 19 |
# File 'lib/daytona/common/snapshot.rb', line 17 def entrypoint @entrypoint end |
#image ⇒ String, Daytona::Image (readonly)
Returns Image of the snapshot. If a string is provided, it should be available on some registry. If an Image instance is provided, it will be used to create a new image in Daytona.
11 12 13 |
# File 'lib/daytona/common/snapshot.rb', line 11 def image @image end |
#name ⇒ String (readonly)
Returns Name of the snapshot.
6 7 8 |
# File 'lib/daytona/common/snapshot.rb', line 6 def name @name end |
#region_id ⇒ String? (readonly)
Returns ID of the region where the snapshot will be available. Defaults to organization default region if not specified.
21 22 23 |
# File 'lib/daytona/common/snapshot.rb', line 21 def region_id @region_id end |
#resources ⇒ Daytona::Resources? (readonly)
Returns Resources of the snapshot.
14 15 16 |
# File 'lib/daytona/common/snapshot.rb', line 14 def resources @resources end |