Class: Daytona::Process
- Inherits:
-
Object
- Object
- Daytona::Process
- Includes:
- Instrumentation
- Defined in:
- lib/daytona/process.rb
Overview
rubocop:disable Metrics/ClassLength
Instance Attribute Summary collapse
-
#get_preview_link ⇒ Proc
readonly
Function to get preview link for a port.
-
#language ⇒ String
readonly
The language for code execution (e.g. ‘python’, ‘typescript’, ‘javascript’).
-
#sandbox_id ⇒ String
readonly
The ID of the Sandbox.
-
#toolbox_api ⇒ DaytonaToolboxApiClient::ProcessApi
readonly
API client for Sandbox operations.
Instance Method Summary collapse
-
#code_run(code:, params: nil, timeout: nil) ⇒ ExecuteResponse
Execute code in the Sandbox using the appropriate language runtime.
-
#connect_pty_session(session_id) ⇒ PtyHandle
Connects to an existing PTY session in the Sandbox.
-
#create_pty_session(id:, cwd: nil, envs: nil, pty_size: nil) ⇒ PtyHandle
Creates a new PTY (pseudo-terminal) session in the Sandbox.
-
#create_session(session_id) ⇒ void
Creates a new long-running background session in the Sandbox.
-
#delete_pty_session(session_id) ⇒ void
Deletes a PTY session, terminating the associated process.
-
#delete_session(session_id) ⇒ Object
Terminates and removes a session from the Sandbox, cleaning up any resources associated with it.
-
#exec(command:, cwd: nil, env: nil, timeout: nil) ⇒ ExecuteResponse
Execute a shell command in the Sandbox.
-
#execute_session_command(session_id:, req:) ⇒ Daytona::SessionExecuteResponse
Executes a command in the session.
-
#get_entrypoint_logs ⇒ Daytona::SessionCommandLogsResponse
Get the sandbox entrypoint logs.
-
#get_entrypoint_logs_async(on_stdout:, on_stderr:) ⇒ WebSocket::Client::Simple::Client
Asynchronously retrieves and processes the sandbox entrypoint logs as they become available.
-
#get_entrypoint_session ⇒ DaytonaApiClient::Session
Gets the Sandbox entrypoint session.
-
#get_pty_session_info(session_id) ⇒ DaytonaApiClient::PtySessionInfo
Gets detailed information about a specific PTY session.
-
#get_session(session_id) ⇒ DaytonaApiClient::Session
Gets a session in the Sandbox.
-
#get_session_command(session_id:, command_id:) ⇒ DaytonaApiClient::Command
Gets information about a specific command executed in a session.
-
#get_session_command_logs(session_id:, command_id:) ⇒ Daytona::SessionCommandLogsResponse
Get the logs for a command executed in a session.
-
#get_session_command_logs_async(session_id:, command_id:, on_stdout:, on_stderr:) ⇒ WebSocket::Client::Simple::Client
Asynchronously retrieves and processes the logs for a command executed in a session as they become available.
-
#initialize(sandbox_id:, toolbox_api:, get_preview_link:, language: 'python', otel_state: nil) ⇒ Process
constructor
Initialize a new Process instance.
-
#list_pty_sessions ⇒ Array<DaytonaApiClient::PtySessionInfo>
Lists all PTY sessions in the Sandbox.
-
#list_sessions ⇒ Array<DaytonaApiClient::Session>
List of all sessions in the Sandbox.
-
#resize_pty_session(session_id, pty_size) ⇒ DaytonaApiClient::PtySessionInfo
Resizes a PTY session to the specified dimensions.
-
#send_session_command_input(session_id:, command_id:, data:) ⇒ void
Sends input data to a command executed in a session.
Methods included from Instrumentation
Constructor Details
#initialize(sandbox_id:, toolbox_api:, get_preview_link:, language: 'python', otel_state: nil) ⇒ Process
Initialize a new Process instance
28 29 30 31 32 33 34 |
# File 'lib/daytona/process.rb', line 28 def initialize(sandbox_id:, toolbox_api:, get_preview_link:, language: 'python', otel_state: nil) @sandbox_id = sandbox_id @toolbox_api = toolbox_api @get_preview_link = get_preview_link @language = language @otel_state = otel_state end |
Instance Attribute Details
#get_preview_link ⇒ Proc (readonly)
Returns Function to get preview link for a port.
16 17 18 |
# File 'lib/daytona/process.rb', line 16 def get_preview_link @get_preview_link end |
#language ⇒ String (readonly)
Returns The language for code execution (e.g. ‘python’, ‘typescript’, ‘javascript’).
19 20 21 |
# File 'lib/daytona/process.rb', line 19 def language @language end |
#sandbox_id ⇒ String (readonly)
Returns The ID of the Sandbox.
10 11 12 |
# File 'lib/daytona/process.rb', line 10 def sandbox_id @sandbox_id end |
#toolbox_api ⇒ DaytonaToolboxApiClient::ProcessApi (readonly)
Returns API client for Sandbox operations.
13 14 15 |
# File 'lib/daytona/process.rb', line 13 def toolbox_api @toolbox_api end |
Instance Method Details
#code_run(code:, params: nil, timeout: nil) ⇒ ExecuteResponse
Execute code in the Sandbox using the appropriate language runtime
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/daytona/process.rb', line 92 def code_run(code:, params: nil, timeout: nil) response = toolbox_api.code_run( DaytonaToolboxApiClient::CodeRunRequest.new( code:, language:, argv: params&.argv, envs: params&.env, timeout: ) ) ExecuteResponse.new( exit_code: response.exit_code, result: response.result, artifacts: ExecutionArtifacts.new(response.result, (response.artifacts&.charts || []).map do |c| Charts.parse_chart(c) end) ) end |
#connect_pty_session(session_id) ⇒ PtyHandle
Connects to an existing PTY session in the Sandbox.
Establishes a WebSocket connection to an existing PTY session, allowing you to interact with a previously created terminal session.
451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/daytona/process.rb', line 451 def connect_pty_session(session_id) # rubocop:disable Metrics/AbcSize, Metrics/MethodLength preview_link = get_preview_link.call(WS_PORT) url = URI.parse(preview_link.url) url.scheme = url.scheme == 'https' ? 'wss' : 'ws' url.path = "/process/pty/#{session_id}/connect" PtyHandle.new( WebSocket::Client::Simple.connect( url.to_s, headers: toolbox_api.api_client.default_headers.dup.merge( 'X-Daytona-Preview-Token' => preview_link.token ) ), session_id:, handle_resize: ->(pty_size) { resize_pty_session(session_id, pty_size) }, handle_kill: -> { delete_pty_session(session_id) } ).tap(&:wait_for_connection) end |
#create_pty_session(id:, cwd: nil, envs: nil, pty_size: nil) ⇒ PtyHandle
Creates a new PTY (pseudo-terminal) session in the Sandbox.
Creates an interactive terminal session that can execute commands and handle user input. The PTY session behaves like a real terminal, supporting features like command history.
419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/daytona/process.rb', line 419 def create_pty_session(id:, cwd: nil, envs: nil, pty_size: nil) # rubocop:disable Metrics/MethodLength response = toolbox_api.create_pty_session( DaytonaToolboxApiClient::PtyCreateRequest.new( id:, cwd:, envs:, cols: pty_size&.cols, rows: pty_size&.rows, lazy_start: true ) ) connect_pty_session(response.session_id) end |
#create_session(session_id) ⇒ void
This method returns an undefined value.
Creates a new long-running background session in the Sandbox
Sessions are background processes that maintain state between commands, making them ideal for scenarios requiring multiple related commands or persistent environment setup.
123 124 125 |
# File 'lib/daytona/process.rb', line 123 def create_session(session_id) toolbox_api.create_session(DaytonaToolboxApiClient::CreateSessionRequest.new(session_id:)) end |
#delete_pty_session(session_id) ⇒ void
This method returns an undefined value.
Deletes a PTY session, terminating the associated process
498 499 500 |
# File 'lib/daytona/process.rb', line 498 def delete_pty_session(session_id) toolbox_api.delete_pty_session(session_id) end |
#delete_session(session_id) ⇒ Object
Terminates and removes a session from the Sandbox, cleaning up any resources associated with it
384 |
# File 'lib/daytona/process.rb', line 384 def delete_session(session_id) = toolbox_api.delete_session(session_id) |
#exec(command:, cwd: nil, env: nil, timeout: nil) ⇒ ExecuteResponse
Execute a shell command in the Sandbox
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/daytona/process.rb', line 55 def exec(command:, cwd: nil, env: nil, timeout: nil) envs = nil if env && !env.empty? env.each_key do |key| unless key.match?(/\A[A-Za-z_][A-Za-z0-9_]*\z/) raise ArgumentError, "Invalid environment variable name: '#{key}'" end end envs = env end response = toolbox_api.execute_command(DaytonaToolboxApiClient::ExecuteRequest.new(command:, cwd:, envs:, timeout:)) result = response.result || '' ExecuteResponse.new( exit_code: response.exit_code, result:, artifacts: ExecutionArtifacts.new(result, []) ) end |
#execute_session_command(session_id:, req:) ⇒ Daytona::SessionExecuteResponse
Executes a command in the session
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/daytona/process.rb', line 188 def execute_session_command(session_id:, req:) # rubocop:disable Metrics/MethodLength response = toolbox_api.session_execute_command( session_id, DaytonaToolboxApiClient::SessionExecuteRequest.new(command: req.command, run_async: req.run_async, suppress_input_echo: req.suppress_input_echo) ) SessionExecuteResponse.new( cmd_id: response.cmd_id, output: response.output, stdout: response.stdout || '', stderr: response.stderr || '', exit_code: response.exit_code, additional_properties: {} ) end |
#get_entrypoint_logs ⇒ Daytona::SessionCommandLogsResponse
Get the sandbox entrypoint logs
286 287 288 289 |
# File 'lib/daytona/process.rb', line 286 def get_entrypoint_logs response = toolbox_api.get_entrypoint_logs SessionCommandLogsResponse.new(output: response.output, stdout: response.stdout, stderr: response.stderr) end |
#get_entrypoint_logs_async(on_stdout:, on_stderr:) ⇒ WebSocket::Client::Simple::Client
Asynchronously retrieves and processes the sandbox entrypoint logs as they become available
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/daytona/process.rb', line 302 def get_entrypoint_logs_async(on_stdout:, on_stderr:) # rubocop:disable Metrics/AbcSize, Metrics/MethodLength preview_link = get_preview_link.call(WS_PORT) url = URI.parse(preview_link.url) url.scheme = url.scheme == 'https' ? 'wss' : 'ws' url.path = '/process/session/entrypoint/logs' url.query = 'follow=true' completion_queue = Queue.new ws = WebSocket::Client::Simple.connect( url.to_s, headers: toolbox_api.api_client.default_headers.dup.merge( 'X-Daytona-Preview-Token' => preview_link.token, 'Content-Type' => 'text/plain', 'Accept' => 'text/plain' ) ) ws.on(:message) do || if .type == :close ws.close completion_queue.push(:close) else stdout, stderr = Util.demux(.data.to_s) on_stdout.call(stdout) unless stdout.empty? on_stderr.call(stderr) unless stderr.empty? end end ws.on(:close) do completion_queue.push(:close) end ws.on(:error) do |e| completion_queue.push(:error) raise Sdk::Error, "WebSocket error: #{e.}" end # Wait for completion completion_queue.pop end |
#get_entrypoint_session ⇒ DaytonaApiClient::Session
Gets the Sandbox entrypoint session
148 |
# File 'lib/daytona/process.rb', line 148 def get_entrypoint_session = toolbox_api.get_entrypoint_session |
#get_pty_session_info(session_id) ⇒ DaytonaApiClient::PtySessionInfo
Gets detailed information about a specific PTY session
Retrieves comprehensive information about a PTY session including its current state, configuration, and metadata.
531 532 533 |
# File 'lib/daytona/process.rb', line 531 def get_pty_session_info(session_id) toolbox_api.get_pty_session(session_id) end |
#get_session(session_id) ⇒ DaytonaApiClient::Session
Gets a session in the Sandbox
137 |
# File 'lib/daytona/process.rb', line 137 def get_session(session_id) = toolbox_api.get_session(session_id) |
#get_session_command(session_id:, command_id:) ⇒ DaytonaApiClient::Command
Gets information about a specific command executed in a session
161 162 163 |
# File 'lib/daytona/process.rb', line 161 def get_session_command(session_id:, command_id:) toolbox_api.get_session_command(session_id, command_id) end |
#get_session_command_logs(session_id:, command_id:) ⇒ Daytona::SessionCommandLogsResponse
Get the logs for a command executed in a session
215 216 217 218 |
# File 'lib/daytona/process.rb', line 215 def get_session_command_logs(session_id:, command_id:) response = toolbox_api.get_session_command_logs(session_id, command_id) SessionCommandLogsResponse.new(output: response.output, stdout: response.stdout, stderr: response.stderr) end |
#get_session_command_logs_async(session_id:, command_id:, on_stdout:, on_stderr:) ⇒ WebSocket::Client::Simple::Client
Asynchronously retrieves and processes the logs for a command executed in a session as they become available
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/daytona/process.rb', line 235 def get_session_command_logs_async(session_id:, command_id:, on_stdout:, on_stderr:) # rubocop:disable Metrics/AbcSize, Metrics/MethodLength preview_link = get_preview_link.call(WS_PORT) url = URI.parse(preview_link.url) url.scheme = url.scheme == 'https' ? 'wss' : 'ws' url.path = "/process/session/#{session_id}/command/#{command_id}/logs" url.query = 'follow=true' completion_queue = Queue.new ws = WebSocket::Client::Simple.connect( url.to_s, headers: toolbox_api.api_client.default_headers.dup.merge( 'X-Daytona-Preview-Token' => preview_link.token, 'Content-Type' => 'text/plain', 'Accept' => 'text/plain' ) ) ws.on(:message) do || if .type == :close ws.close completion_queue.push(:close) else stdout, stderr = Util.demux(.data.to_s) on_stdout.call(stdout) unless stdout.empty? on_stderr.call(stderr) unless stderr.empty? end end ws.on(:close) do completion_queue.push(:close) end ws.on(:error) do |e| completion_queue.push(:error) raise Sdk::Error, "WebSocket error: #{e.}" end # Wait for completion completion_queue.pop end |
#list_pty_sessions ⇒ Array<DaytonaApiClient::PtySessionInfo>
Lists all PTY sessions in the Sandbox
511 512 513 |
# File 'lib/daytona/process.rb', line 511 def list_pty_sessions toolbox_api.list_pty_sessions end |
#list_sessions ⇒ Array<DaytonaApiClient::Session>
Returns List of all sessions in the Sandbox.
371 |
# File 'lib/daytona/process.rb', line 371 def list_sessions = toolbox_api.list_sessions |
#resize_pty_session(session_id, pty_size) ⇒ DaytonaApiClient::PtySessionInfo
Resizes a PTY session to the specified dimensions
481 482 483 484 485 486 487 488 489 |
# File 'lib/daytona/process.rb', line 481 def resize_pty_session(session_id, pty_size) toolbox_api.resize_pty_session( session_id, DaytonaToolboxApiClient::PtyResizeRequest.new( cols: pty_size.cols, rows: pty_size.rows ) ) end |
#send_session_command_input(session_id:, command_id:, data:) ⇒ void
This method returns an undefined value.
Sends input data to a command executed in a session
This method allows you to send input to an interactive command running in a session, such as responding to prompts or providing data to stdin.
354 355 356 357 358 359 360 |
# File 'lib/daytona/process.rb', line 354 def send_session_command_input(session_id:, command_id:, data:) toolbox_api.send_input( session_id, command_id, DaytonaToolboxApiClient::SessionSendInputRequest.new(data:) ) end |