Class: Daytona::Process
- Inherits:
-
Object
- Object
- Daytona::Process
- Includes:
- Instrumentation
- Defined in:
- lib/daytona/process.rb
Overview
rubocop:disable Metrics/ClassLength
Defined Under Namespace
Modules: ArtifactType
Instance Attribute Summary collapse
-
#code_toolbox ⇒ Daytona::SandboxPythonCodeToolbox,
readonly
Daytona::SandboxPythonCodeToolbox,.
-
#get_preview_link ⇒ Proc
readonly
Function to get preview link for a port.
-
#sandbox_id ⇒ String
readonly
The ID of the Sandbox.
-
#toolbox_api ⇒ DaytonaToolboxApiClient::ProcessApi
readonly
API client for Sandbox operations.
Instance Method Summary collapse
-
#code_run(code:, params: nil, timeout: nil) ⇒ ExecuteResponse
Execute code in the Sandbox using the appropriate language runtime.
-
#connect_pty_session(session_id) ⇒ PtyHandle
Connects to an existing PTY session in the Sandbox.
-
#create_pty_session(id:, cwd: nil, envs: nil, pty_size: nil) ⇒ PtyHandle
Creates a new PTY (pseudo-terminal) session in the Sandbox.
-
#create_session(session_id) ⇒ void
Creates a new long-running background session in the Sandbox.
-
#delete_pty_session(session_id) ⇒ void
Deletes a PTY session, terminating the associated process.
-
#delete_session(session_id) ⇒ Object
Terminates and removes a session from the Sandbox, cleaning up any resources associated with it.
-
#exec(command:, cwd: nil, env: nil, timeout: nil) ⇒ ExecuteResponse
Execute a shell command in the Sandbox.
-
#execute_session_command(session_id:, req:) ⇒ Daytona::SessionExecuteResponse
Executes a command in the session.
-
#get_pty_session_info(session_id) ⇒ DaytonaApiClient::PtySessionInfo
Gets detailed information about a specific PTY session.
-
#get_session(session_id) ⇒ DaytonaApiClient::Session
Gets a session in the Sandbox.
-
#get_session_command(session_id:, command_id:) ⇒ DaytonaApiClient::Command
Gets information about a specific command executed in a session.
-
#get_session_command_logs(session_id:, command_id:) ⇒ Daytona::SessionCommandLogsResponse
Get the logs for a command executed in a session.
-
#get_session_command_logs_async(session_id:, command_id:, on_stdout:, on_stderr:) ⇒ WebSocket::Client::Simple::Client
Asynchronously retrieves and processes the logs for a command executed in a session as they become available.
-
#initialize(code_toolbox:, sandbox_id:, toolbox_api:, get_preview_link:, otel_state: nil) ⇒ Process
constructor
Initialize a new Process instance.
-
#list_pty_sessions ⇒ Array<DaytonaApiClient::PtySessionInfo>
Lists all PTY sessions in the Sandbox.
-
#list_sessions ⇒ Array<DaytonaApiClient::Session>
List of all sessions in the Sandbox.
-
#resize_pty_session(session_id, pty_size) ⇒ DaytonaApiClient::PtySessionInfo
Resizes a PTY session to the specified dimensions.
-
#send_session_command_input(session_id:, command_id:, data:) ⇒ void
Sends input data to a command executed in a session.
Methods included from Instrumentation
Constructor Details
#initialize(code_toolbox:, sandbox_id:, toolbox_api:, get_preview_link:, otel_state: nil) ⇒ Process
Initialize a new Process instance
30 31 32 33 34 35 36 |
# File 'lib/daytona/process.rb', line 30 def initialize(code_toolbox:, sandbox_id:, toolbox_api:, get_preview_link:, otel_state: nil) @code_toolbox = code_toolbox @sandbox_id = sandbox_id @toolbox_api = toolbox_api @get_preview_link = get_preview_link @otel_state = otel_state end |
Instance Attribute Details
#code_toolbox ⇒ Daytona::SandboxPythonCodeToolbox, (readonly)
Returns Daytona::SandboxPythonCodeToolbox,.
12 13 14 |
# File 'lib/daytona/process.rb', line 12 def code_toolbox @code_toolbox end |
#get_preview_link ⇒ Proc (readonly)
Returns Function to get preview link for a port.
21 22 23 |
# File 'lib/daytona/process.rb', line 21 def get_preview_link @get_preview_link end |
#sandbox_id ⇒ String (readonly)
Returns The ID of the Sandbox.
15 16 17 |
# File 'lib/daytona/process.rb', line 15 def sandbox_id @sandbox_id end |
#toolbox_api ⇒ DaytonaToolboxApiClient::ProcessApi (readonly)
Returns API client for Sandbox operations.
18 19 20 |
# File 'lib/daytona/process.rb', line 18 def toolbox_api @toolbox_api end |
Instance Method Details
#code_run(code:, params: nil, timeout: nil) ⇒ ExecuteResponse
Execute code in the Sandbox using the appropriate language runtime
98 99 100 |
# File 'lib/daytona/process.rb', line 98 def code_run(code:, params: nil, timeout: nil) exec(command: code_toolbox.get_run_command(code, params), env: params&.env, timeout:) end |
#connect_pty_session(session_id) ⇒ PtyHandle
Connects to an existing PTY session in the Sandbox.
Establishes a WebSocket connection to an existing PTY session, allowing you to interact with a previously created terminal session.
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/daytona/process.rb', line 374 def connect_pty_session(session_id) # rubocop:disable Metrics/AbcSize, Metrics/MethodLength preview_link = get_preview_link.call(WS_PORT) url = URI.parse(preview_link.url) url.scheme = url.scheme == 'https' ? 'wss' : 'ws' url.path = "/process/pty/#{session_id}/connect" PtyHandle.new( WebSocket::Client::Simple.connect( url.to_s, headers: toolbox_api.api_client.default_headers.dup.merge( 'X-Daytona-Preview-Token' => preview_link.token ) ), session_id:, handle_resize: ->(pty_size) { resize_pty_session(session_id, pty_size) }, handle_kill: -> { delete_pty_session(session_id) } ).tap(&:wait_for_connection) end |
#create_pty_session(id:, cwd: nil, envs: nil, pty_size: nil) ⇒ PtyHandle
Creates a new PTY (pseudo-terminal) session in the Sandbox.
Creates an interactive terminal session that can execute commands and handle user input. The PTY session behaves like a real terminal, supporting features like command history.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/daytona/process.rb', line 342 def create_pty_session(id:, cwd: nil, envs: nil, pty_size: nil) # rubocop:disable Metrics/MethodLength response = toolbox_api.create_pty_session( DaytonaToolboxApiClient::PtyCreateRequest.new( id:, cwd:, envs:, cols: pty_size&.cols, rows: pty_size&.rows, lazy_start: true ) ) connect_pty_session(response.session_id) end |
#create_session(session_id) ⇒ void
This method returns an undefined value.
Creates a new long-running background session in the Sandbox
Sessions are background processes that maintain state between commands, making them ideal for scenarios requiring multiple related commands or persistent environment setup.
117 118 119 |
# File 'lib/daytona/process.rb', line 117 def create_session(session_id) toolbox_api.create_session(DaytonaToolboxApiClient::CreateSessionRequest.new(session_id:)) end |
#delete_pty_session(session_id) ⇒ void
This method returns an undefined value.
Deletes a PTY session, terminating the associated process
421 422 423 |
# File 'lib/daytona/process.rb', line 421 def delete_pty_session(session_id) toolbox_api.delete_pty_session(session_id) end |
#delete_session(session_id) ⇒ Object
Terminates and removes a session from the Sandbox, cleaning up any resources associated with it
307 |
# File 'lib/daytona/process.rb', line 307 def delete_session(session_id) = toolbox_api.delete_session(session_id) |
#exec(command:, cwd: nil, env: nil, timeout: nil) ⇒ ExecuteResponse
Execute a shell command in the Sandbox
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/daytona/process.rb', line 57 def exec(command:, cwd: nil, env: nil, timeout: nil) # rubocop:disable Metrics/MethodLength if env && !env.empty? env.each_key do |key| unless key.match?(/\A[A-Za-z_][A-Za-z0-9_]*\z/) raise ArgumentError, "Invalid environment variable name: '#{key}'" end end safe_env_exports = env.map do |key, value| "export #{key}=\"$(echo '#{Base64.strict_encode64(value)}' | base64 -d)\"" end.join('; ') command = "#{safe_env_exports}; #{command}" end response = toolbox_api.execute_command(DaytonaToolboxApiClient::ExecuteRequest.new(command:, cwd:, timeout:)) # Post-process the output to extract ExecutionArtifacts artifacts = parse_output(response.result.split("\n")) # Create new response with processed output and charts ExecuteResponse.new( exit_code: response.exit_code, result: artifacts.stdout, artifacts: artifacts ) end |
#execute_session_command(session_id:, req:) ⇒ Daytona::SessionExecuteResponse
Executes a command in the session
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/daytona/process.rb', line 171 def execute_session_command(session_id:, req:) # rubocop:disable Metrics/MethodLength response = toolbox_api.session_execute_command( session_id, DaytonaToolboxApiClient::SessionExecuteRequest.new(command: req.command, run_async: req.run_async, suppress_input_echo: req.suppress_input_echo) ) stdout, stderr = Util.demux(response.output || '') SessionExecuteResponse.new( cmd_id: response.cmd_id, output: response.output, stdout:, stderr:, exit_code: response.exit_code, # TODO: DaytonaApiClient::SessionExecuteResponse doesn't have additional_properties attribute additional_properties: {} ) end |
#get_pty_session_info(session_id) ⇒ DaytonaApiClient::PtySessionInfo
Gets detailed information about a specific PTY session
Retrieves comprehensive information about a PTY session including its current state, configuration, and metadata.
454 455 456 |
# File 'lib/daytona/process.rb', line 454 def get_pty_session_info(session_id) toolbox_api.get_pty_session(session_id) end |
#get_session(session_id) ⇒ DaytonaApiClient::Session
Gets a session in the Sandbox
131 |
# File 'lib/daytona/process.rb', line 131 def get_session(session_id) = toolbox_api.get_session(session_id) |
#get_session_command(session_id:, command_id:) ⇒ DaytonaApiClient::Command
Gets information about a specific command executed in a session
144 145 146 |
# File 'lib/daytona/process.rb', line 144 def get_session_command(session_id:, command_id:) toolbox_api.get_session_command(session_id, command_id) end |
#get_session_command_logs(session_id:, command_id:) ⇒ Daytona::SessionCommandLogsResponse
Get the logs for a command executed in a session
201 202 203 204 205 206 207 208 |
# File 'lib/daytona/process.rb', line 201 def get_session_command_logs(session_id:, command_id:) parse_session_command_logs( toolbox_api.get_session_command_logs( session_id, command_id ) ) end |
#get_session_command_logs_async(session_id:, command_id:, on_stdout:, on_stderr:) ⇒ WebSocket::Client::Simple::Client
Asynchronously retrieves and processes the logs for a command executed in a session as they become available
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/daytona/process.rb', line 225 def get_session_command_logs_async(session_id:, command_id:, on_stdout:, on_stderr:) # rubocop:disable Metrics/AbcSize, Metrics/MethodLength preview_link = get_preview_link.call(WS_PORT) url = URI.parse(preview_link.url) url.scheme = url.scheme == 'https' ? 'wss' : 'ws' url.path = "/process/session/#{session_id}/command/#{command_id}/logs" url.query = 'follow=true' completion_queue = Queue.new ws = WebSocket::Client::Simple.connect( url.to_s, headers: toolbox_api.api_client.default_headers.dup.merge( 'X-Daytona-Preview-Token' => preview_link.token, 'Content-Type' => 'text/plain', 'Accept' => 'text/plain' ) ) ws.on(:message) do || if .type == :close ws.close completion_queue.push(:close) else stdout, stderr = Util.demux(.data.to_s) on_stdout.call(stdout) unless stdout.empty? on_stderr.call(stderr) unless stderr.empty? end end ws.on(:close) do completion_queue.push(:close) end ws.on(:error) do |e| completion_queue.push(:error) raise Sdk::Error, "WebSocket error: #{e.}" end # Wait for completion completion_queue.pop end |
#list_pty_sessions ⇒ Array<DaytonaApiClient::PtySessionInfo>
Lists all PTY sessions in the Sandbox
434 435 436 |
# File 'lib/daytona/process.rb', line 434 def list_pty_sessions toolbox_api.list_pty_sessions end |
#list_sessions ⇒ Array<DaytonaApiClient::Session>
Returns List of all sessions in the Sandbox.
294 |
# File 'lib/daytona/process.rb', line 294 def list_sessions = toolbox_api.list_sessions |
#resize_pty_session(session_id, pty_size) ⇒ DaytonaApiClient::PtySessionInfo
Resizes a PTY session to the specified dimensions
404 405 406 407 408 409 410 411 412 |
# File 'lib/daytona/process.rb', line 404 def resize_pty_session(session_id, pty_size) toolbox_api.resize_pty_session( session_id, DaytonaToolboxApiClient::PtyResizeRequest.new( cols: pty_size.cols, rows: pty_size.rows ) ) end |
#send_session_command_input(session_id:, command_id:, data:) ⇒ void
This method returns an undefined value.
Sends input data to a command executed in a session
This method allows you to send input to an interactive command running in a session, such as responding to prompts or providing data to stdin.
277 278 279 280 281 282 283 |
# File 'lib/daytona/process.rb', line 277 def send_session_command_input(session_id:, command_id:, data:) toolbox_api.send_input( session_id, command_id, DaytonaToolboxApiClient::SessionSendInputRequest.new(data:) ) end |