Class: Daytona::Sandbox
- Inherits:
-
Object
- Object
- Daytona::Sandbox
- Includes:
- Instrumentation
- Defined in:
- lib/daytona/sandbox.rb
Overview
rubocop:disable Metrics/ClassLength
Constant Summary collapse
- DEFAULT_TIMEOUT =
60- SANDBOX_METRIC_FIELD_BY_NAME =
{ 'daytona.sandbox.cpu.utilization' => :cpu_used_pct, 'daytona.sandbox.cpu.limit' => :cpu_count, 'daytona.sandbox.memory.usage' => :mem_used, 'daytona.sandbox.memory.limit' => :mem_total, 'daytona.sandbox.memory.cache' => :mem_cache, 'daytona.sandbox.filesystem.usage' => :disk_used, 'daytona.sandbox.filesystem.total' => :disk_total }.freeze
- SANDBOX_METRIC_NAMES =
SANDBOX_METRIC_FIELD_BY_NAME.keys.freeze
Instance Attribute Summary collapse
-
#auto_archive_interval ⇒ Float
Auto-archive interval in minutes.
-
#auto_delete_interval ⇒ Float
(negative value means disabled, 0 means delete immediately upon stopping).
-
#auto_destroy_at ⇒ String?
readonly
When the sandbox will be automatically destroyed (nil if no TTL is set).
-
#auto_pause_interval ⇒ Float
Auto-pause interval in minutes (0 means disabled).
-
#auto_stop_interval ⇒ Float
Auto-stop interval in minutes (0 means disabled).
-
#backup_created_at ⇒ String?
readonly
The creation timestamp of the last backup.
-
#backup_state ⇒ String
readonly
The state of the backup.
-
#build_info ⇒ DaytonaApiClient::BuildInfo?
readonly
Build information for the sandbox if it was created from a dynamic build.
- #code_interpreter ⇒ Daytona::CodeInterpreter readonly
- #computer_use ⇒ Daytona::ComputerUse readonly
- #config ⇒ Daytona::Config readonly
-
#cpu ⇒ Float
readonly
The CPU quota for the sandbox.
-
#created_at ⇒ String
readonly
The creation timestamp of the sandbox.
-
#daemon_version ⇒ String
readonly
The version of the daemon running in the sandbox.
-
#desired_state ⇒ DaytonaApiClient::SandboxDesiredState
readonly
The desired state of the sandbox.
-
#disk ⇒ Float
readonly
The disk quota for the sandbox.
-
#domain_allow_list ⇒ String?
readonly
Comma-separated list of allowed domains for the sandbox.
-
#env ⇒ Hash<String, String>?
readonly
Environment variables for the sandbox.
-
#error_reason ⇒ String
readonly
The error reason of the sandbox.
- #fs ⇒ Daytona::FileSystem readonly
- #git ⇒ Daytona::Git readonly
-
#gpu ⇒ Float
readonly
The GPU quota for the sandbox.
-
#id ⇒ String
readonly
The ID of the sandbox.
-
#labels ⇒ Hash<String, String>
Labels for the sandbox.
-
#last_activity_at ⇒ String
readonly
The last activity timestamp of the sandbox.
-
#memory ⇒ Float
readonly
The memory quota for the sandbox.
-
#network_allow_list ⇒ String?
readonly
Comma-separated list of allowed CIDR network addresses for the sandbox.
-
#network_block_all ⇒ Boolean?
readonly
Whether to block all network access for the sandbox.
-
#organization_id ⇒ String
readonly
The organization ID of the sandbox.
- #process ⇒ Daytona::Process readonly
-
#public ⇒ Boolean
readonly
Whether the sandbox http preview is public.
- #sandbox_api ⇒ DaytonaApiClient::SandboxApi readonly
-
#snapshot ⇒ String
readonly
The snapshot used for the sandbox.
-
#state ⇒ DaytonaApiClient::SandboxState
readonly
The state of the sandbox.
-
#target ⇒ String
readonly
The target environment for the sandbox.
-
#toolbox_proxy_url ⇒ String
readonly
The toolbox proxy URL used to reach the sandbox's toolbox API.
-
#updated_at ⇒ String
readonly
The last update timestamp of the sandbox.
-
#user ⇒ String
readonly
The user associated with the project.
-
#volumes ⇒ Array<DaytonaApiClient::SandboxVolume>?
readonly
Volumes attached to the sandbox.
Class Method Summary collapse
Instance Method Summary collapse
-
#archive ⇒ void
Archives the sandbox, making it inactive and preserving its state.
-
#create_lsp_server(language_id:, path_to_project:) ⇒ Daytona::LspServer
Creates a new Language Server Protocol (LSP) server instance.
-
#create_signed_preview_url(port, expires_in_seconds = nil) ⇒ DaytonaApiClient::SignedPortPreviewUrl
Creates a signed preview URL for the sandbox at the specified port.
-
#create_ssh_access(expires_in_minutes) ⇒ DaytonaApiClient::SshAccessDto
Creates an SSH access token for the sandbox.
-
#delete(timeout = DEFAULT_TIMEOUT, wait: false) ⇒ void
Deletes the Sandbox.
-
#experimental_create_snapshot(name:, timeout: DEFAULT_TIMEOUT) ⇒ void
Creates a snapshot from the current state of the Sandbox.
-
#experimental_fork(name: nil, timeout: DEFAULT_TIMEOUT) ⇒ Daytona::Sandbox
Forks the Sandbox, creating a new Sandbox with an identical filesystem.
-
#expire_signed_preview_url(port, token) ⇒ void
Expires a signed preview URL for the sandbox at the specified port.
-
#get_metrics(start_time = nil, end_time = nil) ⇒ Array<Daytona::SandboxMetrics>
Gets historical time-series resource usage metrics for the Sandbox.
-
#get_metrics_latest ⇒ Daytona::SandboxMetrics
Gets the most recent resource usage sample directly from the Sandbox daemon.
-
#get_user_home_dir ⇒ String
Gets the user's home directory path for the logged in user inside the Sandbox.
-
#get_work_dir ⇒ String
Gets the working directory path inside the Sandbox.
-
#initialize(sandbox_dto:, config:, sandbox_api:, subscription_manager:, otel_state: nil, analytics_api_url_provider: nil) ⇒ Sandbox
constructor
Internal — obtain sandboxes via Daytona::Daytona#create, Daytona::Daytona#get, or Daytona::Daytona#list rather than constructing directly.
-
#pause(timeout: DEFAULT_TIMEOUT) ⇒ void
Pauses the Sandbox, freezing all running processes.
-
#preview_url(port) ⇒ DaytonaApiClient::PortPreviewUrl
Retrieves the preview link for the sandbox at the specified port.
-
#recover(timeout = DEFAULT_TIMEOUT) ⇒ void
Recovers the Sandbox from a recoverable error and waits for it to be ready.
-
#refresh ⇒ void
Refresh the Sandbox data from the API.
-
#refresh_activity ⇒ void
Refreshes the sandbox activity to reset the timer for automated lifecycle management actions.
-
#resize(resources, timeout = DEFAULT_TIMEOUT) ⇒ void
Resizes the Sandbox resources.
-
#revoke_ssh_access(token) ⇒ void
Revokes an SSH access token for the sandbox.
-
#start(timeout = DEFAULT_TIMEOUT) ⇒ void
Starts the Sandbox and waits for it to be ready.
-
#stop(timeout = DEFAULT_TIMEOUT, force: false) ⇒ void
Stops the Sandbox and waits for it to be stopped.
-
#ttl_minutes=(minutes) ⇒ void
Sets the TTL (time to live) for the Sandbox.
-
#update_env(env: nil, unset: nil) ⇒ void
Updates the Sandbox daemon's process environment.
-
#update_network_settings(network_block_all: nil, network_allow_list: nil, domain_allow_list: nil) ⇒ void
Updates outbound network policy on the runner (block all, restore access, or CIDR allow list).
-
#update_secrets(secrets) ⇒ void
Replaces the set of organization vault secrets mounted in the Sandbox.
-
#validate_ssh_access(token) ⇒ DaytonaApiClient::SshAccessValidationDto
Validates an SSH access token for the sandbox.
-
#wait_for_resize_complete(timeout = DEFAULT_TIMEOUT) ⇒ void
Waits for the Sandbox resize operation to complete.
-
#wait_for_sandbox_start(timeout = DEFAULT_TIMEOUT) ⇒ void
Waits for the Sandbox to reach the 'started' state.
-
#wait_for_sandbox_stop(timeout = DEFAULT_TIMEOUT) ⇒ void
Waits for the Sandbox to reach the 'stopped' state.
Methods included from Instrumentation
Constructor Details
#initialize(sandbox_dto:, config:, sandbox_api:, subscription_manager:, otel_state: nil, analytics_api_url_provider: nil) ⇒ Sandbox
Internal — obtain sandboxes via Daytona::Daytona#create, Daytona::Daytona#get, or Daytona::Daytona#list rather than constructing directly.
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/daytona/sandbox.rb', line 189 def initialize(sandbox_dto:, config:, sandbox_api:, subscription_manager:, otel_state: nil, analytics_api_url_provider: nil) # rubocop:disable Metrics/MethodLength @state_waiters = [] @waiter_mutex = Mutex.new process_response(sandbox_dto) @config = config @sandbox_api = sandbox_api @otel_state = otel_state @analytics_api_url_provider = analytics_api_url_provider @subscription_manager = subscription_manager @sub_id = nil # Create toolbox API clients with dynamic configuration @toolbox_api_config = build_toolbox_api_config toolbox_api_config = @toolbox_api_config # Helper to create API client with authentication header create_authenticated_client = lambda do client = DaytonaToolboxApiClient::ApiClient.new(toolbox_api_config) client.default_headers['Authorization'] = "Bearer #{config.api_key || config.jwt_token}" client.default_headers['X-Daytona-Source'] = 'sdk-ruby' client.default_headers['X-Daytona-SDK-Version'] = Sdk::VERSION client.default_headers['X-Daytona-Organization-ID'] = config.organization_id if config.jwt_token client.user_agent = "sdk-ruby/#{Sdk::VERSION}" client end process_api = DaytonaToolboxApiClient::ProcessApi.new(create_authenticated_client.call) fs_api = DaytonaToolboxApiClient::FileSystemApi.new(create_authenticated_client.call) git_api = DaytonaToolboxApiClient::GitApi.new(create_authenticated_client.call) lsp_api = DaytonaToolboxApiClient::LspApi.new(create_authenticated_client.call) computer_use_api = DaytonaToolboxApiClient::ComputerUseApi.new(create_authenticated_client.call) interpreter_api = DaytonaToolboxApiClient::InterpreterApi.new(create_authenticated_client.call) info_api = DaytonaToolboxApiClient::InfoApi.new(create_authenticated_client.call) server_api = DaytonaToolboxApiClient::ServerApi.new(create_authenticated_client.call) system_api = DaytonaToolboxApiClient::SystemApi.new(create_authenticated_client.call) @process = Process.new( sandbox_id: id, toolbox_api: process_api, get_preview_link: proc { |port| preview_url(port) }, language: (labels || {}).fetch(CODE_TOOLBOX_LANGUAGE_LABEL, 'python'), otel_state: ) @fs = FileSystem.new(sandbox_id: id, toolbox_api: fs_api, otel_state:) @git = Git.new(sandbox_id: id, toolbox_api: git_api, otel_state:) @computer_use = ComputerUse.new(sandbox_id: id, toolbox_api: computer_use_api, otel_state:) @code_interpreter = CodeInterpreter.new( sandbox_id: id, toolbox_api: interpreter_api, get_preview_link: proc { |port| preview_url(port) }, otel_state: ) @lsp_api = lsp_api @info_api = info_api @server_api = server_api @system_api = system_api ensure_subscribed end |
Instance Attribute Details
#auto_archive_interval ⇒ Float
Returns Auto-archive interval in minutes.
128 129 130 |
# File 'lib/daytona/sandbox.rb', line 128 def auto_archive_interval @auto_archive_interval end |
#auto_delete_interval ⇒ Float
(negative value means disabled, 0 means delete immediately upon stopping)
132 133 134 |
# File 'lib/daytona/sandbox.rb', line 132 def auto_delete_interval @auto_delete_interval end |
#auto_destroy_at ⇒ String? (readonly)
Returns When the sandbox will be automatically destroyed (nil if no TTL is set).
144 145 146 |
# File 'lib/daytona/sandbox.rb', line 144 def auto_destroy_at @auto_destroy_at end |
#auto_pause_interval ⇒ Float
Returns Auto-pause interval in minutes (0 means disabled).
125 126 127 |
# File 'lib/daytona/sandbox.rb', line 125 def auto_pause_interval @auto_pause_interval end |
#auto_stop_interval ⇒ Float
Returns Auto-stop interval in minutes (0 means disabled).
122 123 124 |
# File 'lib/daytona/sandbox.rb', line 122 def auto_stop_interval @auto_stop_interval end |
#backup_created_at ⇒ String? (readonly)
Returns The creation timestamp of the last backup. Not returned by list results; call #refresh on each item to populate.
119 120 121 |
# File 'lib/daytona/sandbox.rb', line 119 def backup_created_at @backup_created_at end |
#backup_state ⇒ String (readonly)
Returns The state of the backup.
115 116 117 |
# File 'lib/daytona/sandbox.rb', line 115 def backup_state @backup_state end |
#build_info ⇒ DaytonaApiClient::BuildInfo? (readonly)
Returns Build information for the sandbox if it was created from a dynamic build. Not returned by list results; call #refresh on each item to populate.
141 142 143 |
# File 'lib/daytona/sandbox.rb', line 141 def build_info @build_info end |
#code_interpreter ⇒ Daytona::CodeInterpreter (readonly)
180 181 182 |
# File 'lib/daytona/sandbox.rb', line 180 def code_interpreter @code_interpreter end |
#computer_use ⇒ Daytona::ComputerUse (readonly)
177 178 179 |
# File 'lib/daytona/sandbox.rb', line 177 def computer_use @computer_use end |
#config ⇒ Daytona::Config (readonly)
162 163 164 |
# File 'lib/daytona/sandbox.rb', line 162 def config @config end |
#cpu ⇒ Float (readonly)
Returns The CPU quota for the sandbox.
94 95 96 |
# File 'lib/daytona/sandbox.rb', line 94 def cpu @cpu end |
#created_at ⇒ String (readonly)
Returns The creation timestamp of the sandbox.
147 148 149 |
# File 'lib/daytona/sandbox.rb', line 147 def created_at @created_at end |
#daemon_version ⇒ String (readonly)
Returns The version of the daemon running in the sandbox.
156 157 158 |
# File 'lib/daytona/sandbox.rb', line 156 def daemon_version @daemon_version end |
#desired_state ⇒ DaytonaApiClient::SandboxDesiredState (readonly)
Returns The desired state of the sandbox.
109 110 111 |
# File 'lib/daytona/sandbox.rb', line 109 def desired_state @desired_state end |
#disk ⇒ Float (readonly)
Returns The disk quota for the sandbox.
103 104 105 |
# File 'lib/daytona/sandbox.rb', line 103 def disk @disk end |
#domain_allow_list ⇒ String? (readonly)
Returns Comma-separated list of allowed domains for the sandbox. Not returned by list results; call #refresh on each item to populate.
88 89 90 |
# File 'lib/daytona/sandbox.rb', line 88 def domain_allow_list @domain_allow_list end |
#env ⇒ Hash<String, String>? (readonly)
Returns Environment variables for the sandbox. Not returned by list results; call #refresh on each item to populate.
70 71 72 |
# File 'lib/daytona/sandbox.rb', line 70 def env @env end |
#error_reason ⇒ String (readonly)
Returns The error reason of the sandbox.
112 113 114 |
# File 'lib/daytona/sandbox.rb', line 112 def error_reason @error_reason end |
#fs ⇒ Daytona::FileSystem (readonly)
171 172 173 |
# File 'lib/daytona/sandbox.rb', line 171 def fs @fs end |
#git ⇒ Daytona::Git (readonly)
174 175 176 |
# File 'lib/daytona/sandbox.rb', line 174 def git @git end |
#gpu ⇒ Float (readonly)
Returns The GPU quota for the sandbox.
97 98 99 |
# File 'lib/daytona/sandbox.rb', line 97 def gpu @gpu end |
#id ⇒ String (readonly)
Returns The ID of the sandbox.
57 58 59 |
# File 'lib/daytona/sandbox.rb', line 57 def id @id end |
#labels ⇒ Hash<String, String>
Returns Labels for the sandbox.
73 74 75 |
# File 'lib/daytona/sandbox.rb', line 73 def labels @labels end |
#last_activity_at ⇒ String (readonly)
Returns The last activity timestamp of the sandbox.
153 154 155 |
# File 'lib/daytona/sandbox.rb', line 153 def last_activity_at @last_activity_at end |
#memory ⇒ Float (readonly)
Returns The memory quota for the sandbox.
100 101 102 |
# File 'lib/daytona/sandbox.rb', line 100 def memory @memory end |
#network_allow_list ⇒ String? (readonly)
Returns Comma-separated list of allowed CIDR network addresses for the sandbox. Not returned by list results; call #refresh on each item to populate.
84 85 86 |
# File 'lib/daytona/sandbox.rb', line 84 def network_allow_list @network_allow_list end |
#network_block_all ⇒ Boolean? (readonly)
Returns Whether to block all network access for the sandbox. Not returned by list results; call #refresh on each item to populate.
80 81 82 |
# File 'lib/daytona/sandbox.rb', line 80 def network_block_all @network_block_all end |
#organization_id ⇒ String (readonly)
Returns The organization ID of the sandbox.
60 61 62 |
# File 'lib/daytona/sandbox.rb', line 60 def organization_id @organization_id end |
#process ⇒ Daytona::Process (readonly)
168 169 170 |
# File 'lib/daytona/sandbox.rb', line 168 def process @process end |
#public ⇒ Boolean (readonly)
Returns Whether the sandbox http preview is public.
76 77 78 |
# File 'lib/daytona/sandbox.rb', line 76 def public @public end |
#sandbox_api ⇒ DaytonaApiClient::SandboxApi (readonly)
165 166 167 |
# File 'lib/daytona/sandbox.rb', line 165 def sandbox_api @sandbox_api end |
#snapshot ⇒ String (readonly)
Returns The snapshot used for the sandbox.
63 64 65 |
# File 'lib/daytona/sandbox.rb', line 63 def snapshot @snapshot end |
#state ⇒ DaytonaApiClient::SandboxState (readonly)
Returns The state of the sandbox.
106 107 108 |
# File 'lib/daytona/sandbox.rb', line 106 def state @state end |
#target ⇒ String (readonly)
Returns The target environment for the sandbox.
91 92 93 |
# File 'lib/daytona/sandbox.rb', line 91 def target @target end |
#toolbox_proxy_url ⇒ String (readonly)
Returns The toolbox proxy URL used to reach the sandbox's toolbox API.
159 160 161 |
# File 'lib/daytona/sandbox.rb', line 159 def toolbox_proxy_url @toolbox_proxy_url end |
#updated_at ⇒ String (readonly)
Returns The last update timestamp of the sandbox.
150 151 152 |
# File 'lib/daytona/sandbox.rb', line 150 def updated_at @updated_at end |
#user ⇒ String (readonly)
Returns The user associated with the project.
66 67 68 |
# File 'lib/daytona/sandbox.rb', line 66 def user @user end |
#volumes ⇒ Array<DaytonaApiClient::SandboxVolume>? (readonly)
Returns Volumes attached to the sandbox. Not returned by list results; call #refresh on each item to populate.
136 137 138 |
# File 'lib/daytona/sandbox.rb', line 136 def volumes @volumes end |
Class Method Details
.with_events(*method_names) ⇒ Object
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/daytona/sandbox.rb', line 20 def self.with_events(*method_names) method_names.each do |method_name| original = instance_method(method_name) visibility = if private_method_defined?(method_name, false) :private elsif protected_method_defined?(method_name, false) :protected else :public end define_method(method_name) do |*args, **kwargs, &blk| ensure_subscribed original.bind_call(self, *args, **kwargs, &blk) end case visibility when :private then private method_name when :protected then protected method_name end end end |
Instance Method Details
#archive ⇒ void
This method returns an undefined value.
Archives the sandbox, making it inactive and preserving its state. When sandboxes are archived, the entire filesystem state is moved to cost-effective object storage, making it possible to keep sandboxes available for an extended period. The tradeoff between archived and stopped states is that starting an archived sandbox takes more time, depending on its size. Sandbox must be stopped before archiving.
256 257 258 259 |
# File 'lib/daytona/sandbox.rb', line 256 def archive sandbox_api.archive_sandbox(id) refresh end |
#create_lsp_server(language_id:, path_to_project:) ⇒ Daytona::LspServer
Creates a new Language Server Protocol (LSP) server instance. The LSP server provides language-specific features like code completion, diagnostics, and more.
713 714 715 |
# File 'lib/daytona/sandbox.rb', line 713 def create_lsp_server(language_id:, path_to_project:) LspServer.new(language_id:, path_to_project:, toolbox_api: @lsp_api, sandbox_id: id, otel_state:) end |
#create_signed_preview_url(port, expires_in_seconds = nil) ⇒ DaytonaApiClient::SignedPortPreviewUrl
Creates a signed preview URL for the sandbox at the specified port.
538 539 540 |
# File 'lib/daytona/sandbox.rb', line 538 def create_signed_preview_url(port, expires_in_seconds = nil) sandbox_api.get_signed_port_preview_url(id, port, { expires_in_seconds: }) end |
#create_ssh_access(expires_in_minutes) ⇒ DaytonaApiClient::SshAccessDto
Creates an SSH access token for the sandbox.
377 378 379 |
# File 'lib/daytona/sandbox.rb', line 377 def create_ssh_access(expires_in_minutes) sandbox_api.create_ssh_access(id, { expires_in_minutes: }) end |
#delete(timeout = DEFAULT_TIMEOUT, wait: false) ⇒ void
This method returns an undefined value.
Deletes the Sandbox.
By default returns as soon as the deletion request is accepted (matching
origin/main behavior). Pass wait: true to block until the Sandbox
reaches the destroyed state.
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/daytona/sandbox.rb', line 391 def delete(timeout = DEFAULT_TIMEOUT, wait: false) # rubocop:disable Metrics/AbcSize,Metrics/MethodLength begin process_response(sandbox_api.delete_sandbox(id)) rescue DaytonaApiClient::ApiError => e raise unless e.code == 404 apply_state(DaytonaApiClient::SandboxState::DESTROYED) end if wait refresh_data_safe else begin refresh rescue DaytonaApiClient::ApiError => e raise unless e.code == 404 apply_state(DaytonaApiClient::SandboxState::DESTROYED) end return end return if state.to_s == DaytonaApiClient::SandboxState::DESTROYED.to_s with_timeout( timeout:, message: "Sandbox #{id} failed to be destroyed within the #{timeout} seconds timeout period", setup: nil ) do wait_for_state( target_states: [DaytonaApiClient::SandboxState::DESTROYED], error_states: [DaytonaApiClient::SandboxState::ERROR, DaytonaApiClient::SandboxState::BUILD_FAILED], safe_refresh: true ) end ensure unsubscribe_from_events end |
#experimental_create_snapshot(name:, timeout: DEFAULT_TIMEOUT) ⇒ void
This method returns an undefined value.
Creates a snapshot from the current state of the Sandbox. The Sandbox will temporarily enter a 'snapshotting' state and return to its previous state when complete.
797 798 799 800 801 802 803 804 805 806 |
# File 'lib/daytona/sandbox.rb', line 797 def experimental_create_snapshot(name:, timeout: DEFAULT_TIMEOUT) with_timeout( timeout:, message: "Sandbox #{id} snapshot failed within the #{timeout} seconds timeout period", setup: proc { response = sandbox_api.create_sandbox_snapshot(id, DaytonaApiClient::CreateSandboxSnapshot.new(name:)) process_response(response) } ) { wait_for_snapshot_complete } end |
#experimental_fork(name: nil, timeout: DEFAULT_TIMEOUT) ⇒ Daytona::Sandbox
Forks the Sandbox, creating a new Sandbox with an identical filesystem. The forked Sandbox is a copy-on-write clone of the original. It starts with the same disk contents but operates independently from that point on.
769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 |
# File 'lib/daytona/sandbox.rb', line 769 def experimental_fork(name: nil, timeout: DEFAULT_TIMEOUT) # rubocop:disable Metrics/MethodLength forked_dto = nil with_timeout( timeout:, message: "Sandbox #{id} fork failed to become ready within the #{timeout} seconds timeout period", setup: proc { forked_dto = sandbox_api.fork_sandbox(id, DaytonaApiClient::ForkSandbox.new(name:)) } ) do forked = Sandbox.new( sandbox_dto: forked_dto, config:, sandbox_api:, subscription_manager: @subscription_manager, otel_state:, analytics_api_url_provider: @analytics_api_url_provider ) forked.wait_for_sandbox_start(timeout) return forked end end |
#expire_signed_preview_url(port, token) ⇒ void
This method returns an undefined value.
Expires a signed preview URL for the sandbox at the specified port.
550 551 552 |
# File 'lib/daytona/sandbox.rb', line 550 def expire_signed_preview_url(port, token) sandbox_api.expire_signed_port_preview_url(id, port, token) end |
#get_metrics(start_time = nil, end_time = nil) ⇒ Array<Daytona::SandboxMetrics>
Gets historical time-series resource usage metrics for the Sandbox.
497 498 499 500 501 502 503 504 505 506 507 |
# File 'lib/daytona/sandbox.rb', line 497 def get_metrics(start_time = nil, end_time = nil) from, to = metrics_range(start_time, end_time) analytics_api_url = fetch_analytics_api_url if analytics_api_url && !analytics_api_url.empty? pivot_sandbox_metric_points(fetch_analytics_metrics(analytics_api_url, from, to)) else pivot_sandbox_metrics(fetch_proxy_metrics(from, to)) end rescue StandardError => e raise Sdk::Error, "Failed to get sandbox metrics: #{e.}" end |
#get_metrics_latest ⇒ Daytona::SandboxMetrics
Gets the most recent resource usage sample directly from the Sandbox daemon.
Unlike #get_metrics, which returns aggregated historical samples, this returns the single current reading without going through the telemetry backend.
483 484 485 486 487 |
# File 'lib/daytona/sandbox.rb', line 483 def get_metrics_latest sandbox_metrics_from_system_metrics(@system_api.get_system_metrics) rescue StandardError => e raise Sdk::Error, "Failed to get system metrics: #{e.}" end |
#get_user_home_dir ⇒ String
Gets the user's home directory path for the logged in user inside the Sandbox.
436 437 438 439 440 |
# File 'lib/daytona/sandbox.rb', line 436 def get_user_home_dir @info_api.get_user_home_dir.dir rescue StandardError => e raise Sdk::Error, "Failed to get user home directory: #{e.}" end |
#get_work_dir ⇒ String
Gets the working directory path inside the Sandbox.
450 451 452 453 454 |
# File 'lib/daytona/sandbox.rb', line 450 def get_work_dir @info_api.get_work_dir.dir rescue StandardError => e raise Sdk::Error, "Failed to get working directory path: #{e.}" end |
#pause(timeout: DEFAULT_TIMEOUT) ⇒ void
This method returns an undefined value.
Pauses the Sandbox, freezing all running processes.
Completes when the Sandbox has left the pausing state (paused, stopped,
archived, etc.); error states still raise.
814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 |
# File 'lib/daytona/sandbox.rb', line 814 def pause(timeout: DEFAULT_TIMEOUT) with_timeout( timeout:, message: "Sandbox #{id} failed to pause within the #{timeout} seconds timeout period", setup: proc { sandbox_api.pause_sandbox(id) refresh } ) do error_states = [DaytonaApiClient::SandboxState::ERROR, DaytonaApiClient::SandboxState::BUILD_FAILED] exclude = [DaytonaApiClient::SandboxState::PAUSING] + error_states target_states = DaytonaApiClient::SandboxState.all_vars.reject { |s| exclude.include?(s) } wait_for_state(target_states:, error_states:) end end |
#preview_url(port) ⇒ DaytonaApiClient::PortPreviewUrl
Retrieves the preview link for the sandbox at the specified port. If the port is closed, it will be opened automatically. For private sandboxes, a token is included to grant access to the URL.
523 524 525 |
# File 'lib/daytona/sandbox.rb', line 523 def preview_url(port) sandbox_api.get_port_preview_url(id, port) end |
#recover(timeout = DEFAULT_TIMEOUT) ⇒ void
This method returns an undefined value.
Recovers the Sandbox from a recoverable error and waits for it to be ready.
611 612 613 614 615 616 617 618 619 620 621 622 623 624 |
# File 'lib/daytona/sandbox.rb', line 611 def recover(timeout = DEFAULT_TIMEOUT) with_timeout( timeout:, message: "Sandbox #{id} failed to recover within the #{timeout} seconds timeout period", setup: proc { process_response(sandbox_api.recover_sandbox(id)) } ) do wait_for_state( target_states: [DaytonaApiClient::SandboxState::STARTED], error_states: [DaytonaApiClient::SandboxState::ERROR, DaytonaApiClient::SandboxState::BUILD_FAILED] ) end rescue StandardError => e raise Sdk::Error, "Failed to recover sandbox: #{e.}" end |
#refresh ⇒ void
This method returns an undefined value.
Refresh the Sandbox data from the API.
557 558 559 |
# File 'lib/daytona/sandbox.rb', line 557 def refresh process_response(sandbox_api.get_sandbox(id)) end |
#refresh_activity ⇒ void
This method returns an undefined value.
Refreshes the sandbox activity to reset the timer for automated lifecycle management actions.
This method updates the sandbox's last activity timestamp without changing its state. It is useful for keeping long-running sessions alive while there is still user activity.
570 571 572 573 574 575 |
# File 'lib/daytona/sandbox.rb', line 570 def refresh_activity sandbox_api.update_last_activity(id) nil rescue StandardError => e raise Sdk::Error, "Failed to refresh sandbox activity: #{e.}" end |
#resize(resources, timeout = DEFAULT_TIMEOUT) ⇒ void
This method returns an undefined value.
Resizes the Sandbox resources.
Changes the CPU, memory, or disk allocation. Resizing a started sandbox accepts only CPU and memory increases. Disk resize requires a stopped sandbox; disk can only grow. GPU is not resizable — to change GPU, create a new sandbox.
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 |
# File 'lib/daytona/sandbox.rb', line 664 def resize(resources, timeout = DEFAULT_TIMEOUT) raise Sdk::Error, 'Resources must not be nil' if resources.nil? if resources.gpu || resources.gpu_type raise Sdk::Error, 'Resize does not support changes to gpu or gpu_type — to change GPU, create a new sandbox' end with_timeout( timeout:, message: "Sandbox #{id} failed to resize within the #{timeout} seconds timeout period", setup: proc { resize_attrs = {} resize_attrs[:cpu] = resources.cpu if resources.cpu resize_attrs[:memory] = resources.memory if resources.memory resize_attrs[:disk] = resources.disk if resources.disk resize_request = DaytonaApiClient::ResizeSandbox.new(resize_attrs) process_response(sandbox_api.resize_sandbox(id, resize_request)) } ) { wait_for_resize_complete(timeout) } end |
#revoke_ssh_access(token) ⇒ void
This method returns an undefined value.
Revokes an SSH access token for the sandbox.
581 582 583 |
# File 'lib/daytona/sandbox.rb', line 581 def revoke_ssh_access(token) sandbox_api.revoke_ssh_access(id, token:) end |
#start(timeout = DEFAULT_TIMEOUT) ⇒ void
This method returns an undefined value.
Starts the Sandbox and waits for it to be ready.
589 590 591 592 593 594 595 596 597 598 599 600 |
# File 'lib/daytona/sandbox.rb', line 589 def start(timeout = DEFAULT_TIMEOUT) with_timeout( timeout:, message: "Sandbox #{id} failed to become ready within the #{timeout} seconds timeout period", setup: proc { process_response(sandbox_api.start_sandbox(id)) } ) do wait_for_state( target_states: [DaytonaApiClient::SandboxState::STARTED], error_states: [DaytonaApiClient::SandboxState::ERROR, DaytonaApiClient::SandboxState::BUILD_FAILED] ) end end |
#stop(timeout = DEFAULT_TIMEOUT, force: false) ⇒ void
This method returns an undefined value.
Stops the Sandbox and waits for it to be stopped.
631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 |
# File 'lib/daytona/sandbox.rb', line 631 def stop(timeout = DEFAULT_TIMEOUT, force: false) # rubocop:disable Metrics/MethodLength with_timeout( timeout:, message: "Sandbox #{id} failed to become stopped within the #{timeout} seconds timeout period", setup: proc { sandbox_api.stop_sandbox(id, { force: force }) refresh } ) do wait_for_state( target_states: [DaytonaApiClient::SandboxState::STOPPED, DaytonaApiClient::SandboxState::DESTROYED], error_states: [DaytonaApiClient::SandboxState::ERROR, DaytonaApiClient::SandboxState::BUILD_FAILED] ) end end |
#ttl_minutes=(minutes) ⇒ void
This method returns an undefined value.
Sets the TTL (time to live) for the Sandbox. The TTL is re-anchored from the current time. When it elapses the Sandbox is destroyed, regardless of its current state. Use 0 to disable.
367 368 369 370 371 |
# File 'lib/daytona/sandbox.rb', line 367 def ttl_minutes=(minutes) raise Sdk::Error, 'TTL must be a non-negative integer' if minutes.negative? sandbox_api.set_ttl(id, minutes) end |
#update_env(env: nil, unset: nil) ⇒ void
This method returns an undefined value.
Updates the Sandbox daemon's process environment. Newly spawned processes, sessions and PTYs inherit the change; already-running processes keep their existing environment.
466 467 468 469 470 471 |
# File 'lib/daytona/sandbox.rb', line 466 def update_env(env: nil, unset: nil) @server_api.update_env(DaytonaToolboxApiClient::UpdateEnvRequest.new(set: env, unset:)) nil rescue StandardError => e raise Sdk::Error, "Failed to update environment: #{e.}" end |
#update_network_settings(network_block_all: nil, network_allow_list: nil, domain_allow_list: nil) ⇒ void
This method returns an undefined value.
Updates outbound network policy on the runner (block all, restore access, or CIDR allow list).
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/daytona/sandbox.rb', line 292 def update_network_settings(network_block_all: nil, network_allow_list: nil, domain_allow_list: nil) if network_block_all.nil? && network_allow_list.nil? && domain_allow_list.nil? raise Sdk::Error, 'At least one of network_block_all, network_allow_list or domain_allow_list must be provided' end body = DaytonaApiClient::UpdateSandboxNetworkSettings.new( network_block_all:, network_allow_list:, domain_allow_list: ) data = sandbox_api.update_network_settings(id, body) @network_block_all = data.network_block_all @network_allow_list = data.network_allow_list @domain_allow_list = data.domain_allow_list end |
#update_secrets(secrets) ⇒ void
This method returns an undefined value.
Replaces the set of organization vault secrets mounted in the Sandbox. Pass an empty hash to detach all secrets. Rotated, attached or detached secrets take effect for outbound requests within seconds. New environment variables are only visible to processes spawned after the update; a Sandbox created without any secrets must be restarted for newly attached secrets to work.
322 323 324 325 326 327 328 |
# File 'lib/daytona/sandbox.rb', line 322 def update_secrets(secrets) body = DaytonaApiClient::UpdateSandboxSecrets.new( secrets: secrets.map { |env_var, secret_name| { env_var.to_s => secret_name.to_s } } ) data = sandbox_api.update_sandbox_secrets(id, body) process_response(data) end |
#validate_ssh_access(token) ⇒ DaytonaApiClient::SshAccessValidationDto
Validates an SSH access token for the sandbox.
721 722 723 |
# File 'lib/daytona/sandbox.rb', line 721 def validate_ssh_access(token) sandbox_api.validate_ssh_access(token) end |
#wait_for_resize_complete(timeout = DEFAULT_TIMEOUT) ⇒ void
This method returns an undefined value.
Waits for the Sandbox resize operation to complete. Polls the Sandbox status until the state is no longer 'resizing'.
691 692 693 694 695 696 697 698 699 700 701 702 703 |
# File 'lib/daytona/sandbox.rb', line 691 def wait_for_resize_complete(timeout = DEFAULT_TIMEOUT) with_timeout( timeout:, message: "Sandbox #{id} resize did not complete within the #{timeout} seconds timeout period", setup: nil ) do error_states = [DaytonaApiClient::SandboxState::ERROR, DaytonaApiClient::SandboxState::BUILD_FAILED] exclude = [DaytonaApiClient::SandboxState::RESIZING] + error_states target_states = DaytonaApiClient::SandboxState.all_vars.reject { |s| exclude.include?(s) } wait_for_state(target_states:, error_states:) end end |
#wait_for_sandbox_start(timeout = DEFAULT_TIMEOUT) ⇒ void
This method returns an undefined value.
Waits for the Sandbox to reach the 'started' state. Polls the Sandbox status until it reaches the 'started' state or encounters an error.
730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'lib/daytona/sandbox.rb', line 730 def wait_for_sandbox_start(timeout = DEFAULT_TIMEOUT) with_timeout( timeout:, message: "Sandbox #{id} failed to start within the #{timeout} seconds timeout period", setup: nil ) do wait_for_state( target_states: [DaytonaApiClient::SandboxState::STARTED], error_states: [DaytonaApiClient::SandboxState::ERROR, DaytonaApiClient::SandboxState::BUILD_FAILED] ) end end |
#wait_for_sandbox_stop(timeout = DEFAULT_TIMEOUT) ⇒ void
This method returns an undefined value.
Waits for the Sandbox to reach the 'stopped' state. Polls the Sandbox status until it reaches the 'stopped' state or encounters an error. Treats destroyed as stopped to cover ephemeral sandboxes that are automatically deleted after stopping.
749 750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/daytona/sandbox.rb', line 749 def wait_for_sandbox_stop(timeout = DEFAULT_TIMEOUT) with_timeout( timeout:, message: "Sandbox #{id} failed to stop within the #{timeout} seconds timeout period", setup: nil ) do wait_for_state( target_states: [DaytonaApiClient::SandboxState::STOPPED, DaytonaApiClient::SandboxState::DESTROYED], error_states: [DaytonaApiClient::SandboxState::ERROR, DaytonaApiClient::SandboxState::BUILD_FAILED] ) end end |